.. _github-stats-3_10_1:

GitHub statistics for 3.10.1 (Feb 27, 2025)
===========================================

GitHub statistics for 2024/12/14 (tag: v3.10.0) - 2025/02/27

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 14 issues and merged 107 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/98?closed=1>`__

The following 28 authors contributed 241 commits.

* Anselm Hahn
* Antony Lee
* Ben Greiner
* Chaoyi Hu
* Christine P. Chai
* dependabot[bot]
* Elliott Sales de Andrade
* G.D. McBain
* Greg Lucas
* hannah
* hu-xiaonan
* Khushi_29
* Khushikela29
* KIU Shueng Chuan
* Kyle Martin
* Kyle Sunden
* Lumberbot (aka Jack)
* Manthan Nagvekar
* musvaage
* Nathan G. Wiseman
* Oscar Gustafsson
* Owl
* Ruth Comer
* saikarna913
* Scott Shambaugh
* Thomas A Caswell
* Tim Hoffmann
* Trygve Magnus Ræder

GitHub issues and pull requests:

Pull Requests (107):

* :ghpull:`29682`: Backport PR #29680 on branch v3.10.x (DOC: fix the bug of examples\event_handling)
* :ghpull:`29683`: Backport PR #29670 on branch v3.10.x (DOC: change marginal scatter plot to subplot_mosaic)
* :ghpull:`29680`: DOC: fix the bug of examples\event_handling
* :ghpull:`29676`: Backport PR #29666 on branch v3.10.x (DOC: Revising the Figure Legend Demo Example)
* :ghpull:`29675`: Backport PR #29662 on branch v3.10.x (DOC: Move Colorbar parameters to __init__)
* :ghpull:`29662`: DOC: Move Colorbar parameters to __init__
* :ghpull:`29668`: Backport PR #29667 on branch v3.10.x (DOC: remove redundant gridspec from example)
* :ghpull:`29664`: Backport PR #29642 on branch v3.10.x (DOC: Add docstrings to get_usetex and set_usetex in ticker.py)
* :ghpull:`29663`: Backport PR #29075 on branch v3.10.x (Add xaxis and yaxis attributes to Axes docs)
* :ghpull:`29642`: DOC: Add docstrings to get_usetex and set_usetex in ticker.py
* :ghpull:`29661`: Backport PR #29652 on branch v3.10.x (Reorder kwonly kwargs in Colorbar & related docs.)
* :ghpull:`29652`: Reorder kwonly kwargs in Colorbar & related docs.
* :ghpull:`29075`: Add xaxis and yaxis attributes to Axes docs
* :ghpull:`29656`: Backport PR #28437 on branch v3.10.x (Respect array alpha with interpolation_stage='rgba' in _Imagebase::_make_image)
* :ghpull:`29448`: Backport PR #29362 on branch v3.10.0-doc (TYP: semantics of enums in stub files changed)
* :ghpull:`28437`: Respect array alpha with interpolation_stage='rgba' in _Imagebase::_make_image
* :ghpull:`29651`: Backport PR #29650 on branch v3.10.x (Copy-edit "interactive figures & async programming" guide.)
* :ghpull:`29650`: Copy-edit "interactive figures & async programming" guide.
* :ghpull:`29633`: Backport PR #29631 on branch v3.10.x (Add inline notebook to test data)
* :ghpull:`29631`: Add inline notebook to test data
* :ghpull:`29627`: Backport PR #29617 on branch v3.10.x (DOC: Add docstrings to matplotlib.cbook.GrouperView)
* :ghpull:`29617`: DOC: Add docstrings to matplotlib.cbook.GrouperView
* :ghpull:`29625`: Backport PR #29622 on branch v3.10.x (DOC: Move "Infinite lines" example from section "pyplot" to "Lines, bars and markers)
* :ghpull:`29623`: Backport PR #29621 on branch v3.10.x (DOC: Cleanup text rotation in data coordinates example)
* :ghpull:`29619`: Backport PR #29616 on branch v3.10.x (FIX: Fix unit example so that we can unpin numpy<2.1)
* :ghpull:`29616`: FIX: Fix unit example so that we can unpin numpy<2.1
* :ghpull:`29611`: Backport PR #29608 on branch v3.10.x (Remove md5 usage to prevent issues on FIPS enabled systems (closes #29603))
* :ghpull:`29608`: Remove md5 usage to prevent issues on FIPS enabled systems (closes #29603)
* :ghpull:`29609`: Backport PR #29607 on branch v3.10.x (Correct doc for axvline arg x which sets x not y)
* :ghpull:`29604`: Backport PR #29601 on branch v3.10.x (DOC: Duplicate categorical values are mapped to the same position)
* :ghpull:`29598`: Backport PR #29597 on branch v3.10.x (Fix typo in deprecation notes for 3.10.0)
* :ghpull:`29591`: Backport PR #29585 on branch v3.10.x (DOC: Document that tight_layout may not converge)
* :ghpull:`29585`: DOC: Document that tight_layout may not converge
* :ghpull:`29587`: Backport PR #25801 on branch v3.10.x (Remove some examples from Userdemo)
* :ghpull:`29577`: Backport PR #29576 on branch v3.10.x (Remove documentation for no-longer existent ContourSet attributes.)
* :ghpull:`29576`: Remove documentation for no-longer existent ContourSet attributes.
* :ghpull:`29530`: Bump the actions group with 5 updates
* :ghpull:`29564`: Backport PR #29563 on branch v3.10.x (DOC: add color sequences reference example)
* :ghpull:`29563`: DOC: add color sequences reference example
* :ghpull:`29557`: Backport PR #29518: TST: Increase tolerance on more arches
* :ghpull:`29555`: Backport PR #29546 on branch v3.10.x (FIX: pyplot.matshow figure handling)
* :ghpull:`29546`: FIX: pyplot.matshow figure handling
* :ghpull:`29518`: TST: Increase tolerance on more arches
* :ghpull:`29547`: Backport PR #29543 on branch v3.10.x (DOC: Minor improvement on broken_barh())
* :ghpull:`29538`: Backport PR #29536 on branch v3.10.x (Fix typo in solarized example plot.)
* :ghpull:`29531`: Backport PR #29520 on branch v3.10.x (FIX: Correct variable name from _frame to _frames in PillowWriter class)
* :ghpull:`29520`: FIX: Correct variable name from _frame to _frames in PillowWriter class
* :ghpull:`29521`: Backport PR #29509 on branch v3.10.x (MNT: Discourage arrow())
* :ghpull:`29509`: MNT: Discourage arrow()
* :ghpull:`29514`: Backport PR #29511 on branch v3.10.x (DOC: Document the behavior of bar() for categorical x data)
* :ghpull:`29513`: Backport PR #29471 on branch v3.10.x (Fix subplot docs)
* :ghpull:`29511`: DOC: Document the behavior of bar() for categorical x data
* :ghpull:`29471`: Fix subplot docs
* :ghpull:`29500`: Backport PR #29478 on branch v3.10.x (DOC: Added blurb for colorizer objects in what's new for 3.10)
* :ghpull:`29498`: Backport PR #29488 on branch v3.10.x (DOC: Update broken_barh example)
* :ghpull:`29490`: Backport PR #29476 on branch v3.10.x (ci: Enable native ARM builders for wheels)
* :ghpull:`29476`: ci: Enable native ARM builders for wheels
* :ghpull:`29462`: Backport PR #29404 on branch v3.10.x (DOC: scales - built in options and custom scale usefulness)
* :ghpull:`29459`: Backport PR #29456 on branch v3.10.x (DOC: Fix type descriptions in fill_between docstring)
* :ghpull:`29404`: DOC: scales - built in options and custom scale usefulness
* :ghpull:`29458`: Backport PR #29457 on branch v3.10.x (DOC: Use float instead for scalar for type descriptions in docstrings)
* :ghpull:`29456`: DOC: Fix type descriptions in fill_between docstring
* :ghpull:`29457`: DOC: Use float instead for scalar for type descriptions in docstrings
* :ghpull:`29452`: Backport PR #29411 on branch v3.10.x (fix #29410 Modifying Axes' position also alters the original Bbox object used for initialization)
* :ghpull:`29411`: fix #29410 Modifying Axes' position also alters the original Bbox object used for initialization
* :ghpull:`29451`: Backport PR #29449 on branch v3.10.x (ci: Install libnotify4 on all Ubuntu)
* :ghpull:`29449`: ci: Install libnotify4 on all Ubuntu
* :ghpull:`29444`: Backport PR #29442 on branch v3.10.x (DOC: put section headings in 3.10 what's new)
* :ghpull:`29436`: Backport PR #29407 on branch v3.10.x (DOC: Improve log scale example)
* :ghpull:`29432`: Backport PR #29431 on branch v3.10.x (ft2font: Split named instance count from style flags)
* :ghpull:`29431`: ft2font: Split named instance count from style flags
* :ghpull:`29423`: Backport PR #29130 on branch v3.10.x (Raise warning if both c and facecolors are used in scatter plot (... and related improvements in the test suite).)
* :ghpull:`29420`: Backport PR #29406 on branch v3.10.x (DOC: Update scales overview)
* :ghpull:`29417`: Backport PR #29409 on branch v3.10.x (Fixed test case(test_axes.py) failing on ppc64le)
* :ghpull:`29416`: Backport PR #29382 on branch v3.10.x (Fix title position for polar plots)
* :ghpull:`29382`: Fix title position for polar plots
* :ghpull:`29412`: Backport PR #29363 on branch v3.10.x (FIX: Add version gate to GTK4 calls when necessary)
* :ghpull:`29409`: Fixed test case(test_axes.py) failing on ppc64le
* :ghpull:`29363`: FIX: Add version gate to GTK4 calls when necessary
* :ghpull:`29408`: Backport PR #29401 on branch v3.10.x (FIX: add errorbars with ``add_container``)
* :ghpull:`29401`: FIX: add errorbars with ``add_container``
* :ghpull:`29130`: Raise warning if both c and facecolors are used in scatter plot (... and related improvements in the test suite).
* :ghpull:`29390`: Backport PR #29389 on branch v3.10.x (DOC: Minor improvements on VPacker, HPacker, PaddedBox docs)
* :ghpull:`29389`: DOC: Minor improvements on VPacker, HPacker, PaddedBox docs
* :ghpull:`29371`: Backport PR #29353 on branch v3.10.x (DOC: Improve module docs of matplotlib.scale)
* :ghpull:`29361`: Backport PR #29355 on branch v3.10.x (Add QtCore.Slot() decorations to FigureCanvasQT)
* :ghpull:`29369`: Backport PR #29362 on branch v3.10.x (TYP: semantics of enums in stub files changed)
* :ghpull:`29353`: DOC: Improve module docs of matplotlib.scale
* :ghpull:`29362`: TYP: semantics of enums in stub files changed
* :ghpull:`29365`: Backport PR #29364 on branch v3.10.x (fix typo)
* :ghpull:`29366`: Backport PR #29347 on branch v3.10.x (DOC: Explain parameters linthresh and linscale of symlog scale)
* :ghpull:`29364`: fix typo
* :ghpull:`29355`: Add QtCore.Slot() decorations to FigureCanvasQT
* :ghpull:`29351`: Backport PR #29348 on branch v3.10.x (DOC: Cleanup scales examples)
* :ghpull:`29336`: Backport PR #29328 on branch v3.10.x (Bump github/codeql-action from 3.27.6 to 3.27.9 in the actions group)
* :ghpull:`29328`: Bump github/codeql-action from 3.27.6 to 3.27.9 in the actions group
* :ghpull:`29330`: Backport PR #29321 on branch v3.10.x (DOC: List min. Python version for Matplotlib 3.10)
* :ghpull:`29324`: Backport PR #29258 on branch v3.10.x (Adding font Size as default parameter)
* :ghpull:`29326`: Backport PR #29323 on branch v3.10.x (DOC: Don't put quotes around coordinate system names)
* :ghpull:`29323`: DOC: Don't put quotes around coordinate system names
* :ghpull:`29258`: Adding font Size as default parameter
* :ghpull:`29320`: Backport PR #29317 on branch v3.10.x (FIX: pass renderer through ``_auto_legend_data``)
* :ghpull:`29317`: FIX: pass renderer through ``_auto_legend_data``
* :ghpull:`29315`: Backport PR #29314 on branch v3.10.x (DOC: fix footnote in choosing colormaps guide)
* :ghpull:`29309`: Backport PR #29308 on branch v3.10.x (Update cibuildwheel workflow)
* :ghpull:`29310`: Backport PR #29292 on branch v3.10.x (Update dependencies.rst)
* :ghpull:`29308`: Update cibuildwheel workflow

Issues (14):

* :ghissue:`28382`: [Bug]: interpolation_stage="rgba" does not respect array-alpha
* :ghissue:`28780`: Doc build fails with numpy>=2.1.0
* :ghissue:`29603`: [Bug]: Setting ``text.usetex=True`` in ``pyplot.rcParams`` Raises FIPS Compliance Errors
* :ghissue:`29575`: [Doc]: QuadContourSet does not contain a collections attribute like stated in the manual
* :ghissue:`29519`: [Bug]:  'PillowWriter' object has no attribute '_frame' shouldn't be  '_frames'?
* :ghissue:`29507`: [Bug]: Duplicating the labels in the ``height``/``width`` argument in ``barh()``/``bar`` leads to undrawn bars
* :ghissue:`29447`: [Doc]: ``subplot`` behavior is not same as the doc reads in 3.10(stable)
* :ghissue:`29410`: [Bug]: Modifying Axes' position also alters the original Bbox object used for initialization
* :ghissue:`29396`: [Bug]: Style flag errors trying to save figures as PDF with font Inter
* :ghissue:`29381`: [Bug]: title position incorrect for polar plot
* :ghissue:`29350`: [Bug]: Matplotlib causes segmentation fault when hovering mouse over graph
* :ghissue:`25274`: [Bug]: .remove() on ErrorbarContainer object does not remove the corresponding item from the legend
* :ghissue:`29202`: [Bug]: ``fontsize`` in tables not working
* :ghissue:`29301`: [Bug]: Blank EPS output with legend and annotate
